@@ -114,6 +114,14 @@
    Also, when `ordering' is RETURN_IN_ORDER,
    each non-option ARGV-element is returned here.  */
 
+/*
+ * On some versions of Solaris, opterr and friends are defined in core libc
+ * rather than in a separate getopt module.  Define these variables only
+ * if configure found they aren't there by default.  (We assume that testing
+ * opterr is sufficient for all of these except optreset.)
+ */
+#ifndef HAVE_INT_OPTERR
+
 char     *optarg = NULL;
 
 /* Index in ARGV of the next element to be scanned.
@@ -128,9 +136,28 @@ char     *optarg = NULL;
    Otherwise, `optind' communicates from one call to the next
    how much of ARGV has been scanned so far.  */
 
+/* Callers store zero here to inhibit the error message
+   for unrecognized options.  */
+
+int       opterr = 1;
+
+/* Set to an option character which was unrecognized.
+   This must be initialized on some systems to avoid linking in the
+   system's own getopt implementation.  */
+
+int       optopt = '?';
+
 /* 1003.2 says this must be 1 before any call.  */
 int       optind = 1;
 
+#else
+ extern int      opterr;
+ extern int      optind;
+ extern int      optopt;
+ extern char     *optarg;
+#endif
+
+
 /* Formerly, initialization of getopt depended on optind==0, which
    causes problems with re-calling getopt as programs generally don't
    know that. */
@@ -146,16 +173,6 @@ int       __getopt_initialized = 0;
 
 static char *nextchar;
 
-/* Callers store zero here to inhibit the error message
-   for unrecognized options.  */
-
-int       opterr = 1;
-
-/* Set to an option character which was unrecognized.
-   This must be initialized on some systems to avoid linking in the
-   system's own getopt implementation.  */
-
-int       optopt = '?';
 
 /* Describe how to deal with options that follow non-option ARGV-elements.
 
